Elements of a PDF document.
This module provides implementations of the Element trait that can be used to render and
arrange text and shapes.
It includes the following elements:
- Containers:
LinearLayout: arranges its elements sequentiallyTableLayout: arranges its elements in columns and rowsOrderedListandUnorderedList: arrange their elements sequentially with bullet points
- Text:
- Wrappers:
FramedElement: draws a frame around the wrapped elementPaddedElement: adds a padding to the wrapped elementStyledElement: sets a default style for the wrapped element and its children
- Other:
You can create custom elements by implementing the Element trait.
Structs
- Break
- A line break.
- Bullet
Point - A bullet point in a list.
- Frame
Cell Decorator - A cell decorator that draws frames around table cells.
- Framed
Element - Adds a frame around the wrapped element.
- Image
- An image to embed in the PDF.
- Linear
Layout - Arranges a list of elements sequentially.
- Ordered
List - An ordered list of elements with arabic numbers.
- Padded
Element - Adds a padding to the wrapped element.
- Page
Break - A page break.
- Paragraph
- A multi-line wrapped paragraph of formatted text.
- Styled
Element - Adds a default style to the wrapped element and its children.
- Table
Layout - Arranges elements in columns and rows.
- Table
Layout Row - A row of a table layout.
- Text
- A single line of formatted text.
- Unordered
List - An unordered list of elements with bullet points.
Traits
- Cell
Decorator - A decorator for table cells.