BulletPoint

Struct BulletPoint 

pub struct BulletPoint<E: Element> { /* private fields */ }
A bullet point in a list.

This is a helper element for the OrderedList and UnorderedList types, but you can also use it directly if you have special requirements.

Example

use genpdf::elements;
let layout = elements::LinearLayout::vertical()
    .element(elements::BulletPoint::new(elements::Paragraph::new("first"))
        .with_bullet("a)"))
    .element(elements::BulletPoint::new(elements::Paragraph::new("second"))
        .with_bullet("b)"));

Implementations

Source

impl<E: Element> BulletPoint<E>

pub fn new(element: E) -> BulletPoint<E>

Creates a new bullet point with the given element.

pub fn set_bullet(&mut self, bullet: impl Into<String>)

Sets the bullet point symbol for this bullet point.

pub fn with_bullet(self, bullet: impl Into<String>) -> Self

Sets the bullet point symbol for this bullet point and returns the bullet point.