TableLayoutRow

Struct TableLayoutRow 

pub struct TableLayoutRow<'a> { /* private fields */ }
A row of a table layout.

This is a helper struct for populating a TableLayout. After you have added all elements to the row using push_element or element, you can append the row to the table layout by calling push.

Examples

With setters:

use genpdf::elements;
let mut table = elements::TableLayout::new(vec![1, 1]);
let mut row = table.row();
row.push_element(elements::Paragraph::new("Cell 1"));
row.push_element(elements::Paragraph::new("Cell 2"));
row.push().expect("Invalid table row");

Chained:

use genpdf::elements;
let table = elements::TableLayout::new(vec![1, 1])
    .row()
    .element(elements::Paragraph::new("Cell 1"))
    .element(elements::Paragraph::new("Cell 2"))
    .push()
    .expect("Invalid table row");

Implementations

Source

impl<'a> TableLayoutRow<'a>

pub fn push_element<E: Element + 'static>(&mut self, element: E)

Adds the given element to this row.

pub fn element<E: Element + 'static>(self, element: E) -> Self

Adds the given element to this row and returns the row.

pub fn push(self) -> Result<(), Error>

Tries to append this row to the table.

This method fails if the number of elements in this row does not match the number of columns in the table.