UnorderedList

Struct UnorderedList 

pub struct UnorderedList { /* private fields */ }
An unordered list of elements with bullet points.

Examples

With setters:

use genpdf::elements;
let mut list = elements::UnorderedList::new();
list.push(elements::Paragraph::new("first"));
list.push(elements::Paragraph::new("second"));
list.push(elements::Paragraph::new("third"));

With setters and a custom bullet symbol:

use genpdf::elements;
let mut list = elements::UnorderedList::with_bullet("*");
list.push(elements::Paragraph::new("first"));
list.push(elements::Paragraph::new("second"));
list.push(elements::Paragraph::new("third"));

Chained:

use genpdf::elements;
let list = elements::UnorderedList::new()
    .element(elements::Paragraph::new("first"))
    .element(elements::Paragraph::new("second"))
    .element(elements::Paragraph::new("third"));

Implementations

Source

impl UnorderedList

pub fn new() -> UnorderedList

Creates a new unordered list with the default bullet point symbol.

pub fn with_bullet(bullet: impl Into<String>) -> UnorderedList

Creates a new unordered list with the given bullet point symbol.

pub fn push<E: Element + 'static>(&mut self, element: E)

Adds an element to this list.

pub fn element<E: Element + 'static>(self, element: E) -> Self

Adds an element to this list and returns the list.